// 	$Id: main.m,v 1.6 1998/03/30 23:17:21 alex Exp $	

#import "BoolNetObserverSwarm.h"
#import "BoolNetBatchSwarm.h"
#import <graph.h>
#import <boolnet.h>
#import <simtoolsgui.h>

int
main (int argc, const char **argv)
{
  BoolNetObserverSwarm * observerSwarm;
  BoolNetBatchSwarm * batchSwarm;

  initSwarm (argc, argv);  
  initGraphLibrary ();
  initBoolLibrary ();

  // swarmGUIMode is set in initSwarm(). It's set to be 1 if your
  // DISPLAY environment variable is set (ie, you have an X server to
  // do graphics with). Otherwise, it's set to 0.
  
  if (swarmGUIMode == 1)
    {
      observerSwarm = [BoolNetObserverSwarm createBegin: globalZone];
      SET_WINDOW_GEOMETRY_RECORD_NAME (observerSwarm);
      observerSwarm = [observerSwarm createEnd];
      [observerSwarm buildObjects];
      [observerSwarm buildActions];
      [observerSwarm activateIn: nil];
      [observerSwarm go];
    }
  else
    {
      batchSwarm = [BoolNetBatchSwarm create: globalZone];
      [batchSwarm buildObjects];
      [batchSwarm buildActions];
      [batchSwarm activateIn: nil];
      [batchSwarm go];
    }
  
  return 0;
}
